@@ -1,3 +1,4 @@
+from braintree.ach_mandate import AchMandate
 from braintree.add_on import AddOn
 from braintree.add_on_gateway import AddOnGateway
 from braintree.address import Address
@@ -8,6 +9,8 @@ from braintree.apple_pay_card import ApplePayCard
 from braintree.braintree_gateway import BraintreeGateway
 from braintree.client_token import ClientToken
 from braintree.configuration import Configuration
+from braintree.connected_merchant_status_transitioned import ConnectedMerchantStatusTransitioned
+from braintree.connected_merchant_paypal_status_changed import ConnectedMerchantPayPalStatusChanged
 from braintree.credentials_parser import CredentialsParser
 from braintree.credit_card import CreditCard
 from braintree.credit_card_gateway import CreditCardGateway
@@ -18,13 +21,19 @@ from braintree.customer_gateway import CustomerGateway
 from braintree.customer_search import CustomerSearch
 from braintree.descriptor import Descriptor
 from braintree.disbursement import Disbursement
+from braintree.document_upload import DocumentUpload
+from braintree.document_upload_gateway import DocumentUploadGateway
 from braintree.discount import Discount
 from braintree.discount_gateway import DiscountGateway
+from braintree.dispute import Dispute
+from braintree.dispute_search import DisputeSearch
 from braintree.environment import Environment
 from braintree.error_codes import ErrorCodes
 from braintree.error_result import ErrorResult
 from braintree.errors import Errors
 from braintree.europe_bank_account import EuropeBankAccount
+from braintree.us_bank_account import UsBankAccount
+from braintree.ideal_payment import IdealPayment
 from braintree.merchant import Merchant
 from braintree.merchant_account import MerchantAccount
 from braintree.merchant_account_gateway import MerchantAccountGateway
